==> flexible-process-springboot-1.3.0.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDesk_11_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "ManualAssignment", processName = "serviceDesk")
public class ServiceDesk_11_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("supportCase", this.supportCase);
        return params;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }
}
// Task output model for user task 'Manual assignment' in process 'serviceDesk'

==> flexible-process-springboot-1.4.1.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDesk_11_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "ManualAssignment", processName = "serviceDesk")
public class ServiceDesk_11_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("supportCase", this.supportCase);
        return params;
    }

    public static ServiceDesk_11_TaskOutput fromMap(Map<String, Object> params) {
        org.kie.flexible.kogito.example.ServiceDesk_11_TaskOutput result = new ServiceDesk_11_TaskOutput();
        result.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        return result;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }
}
// Task output model for user task 'Manual assignment' in process 'serviceDesk'
